from django.core.cache import cache

from .conf import MAIL_TOOLBAR_CACHE_KEY, MAIL_TOOLBAR_TTL

def load_outbox():
    """
    Returns a dictionary of cached mail.
    """
    return cache.get(MAIL_TOOLBAR_CACHE_KEY, {})

def save_outbox(outbox):
    """
    Saves the dictionary of cached mail and sets expiry.
    """
    cache.set(MAIL_TOOLBAR_CACHE_KEY, outbox, MAIL_TOOLBAR_TTL)



import os
import sys
from pathlib import Path

from setuptools import find_packages, setup

# allow setup.py to be run from any path
os.chdir(str(Path(__file__).absolute().parent))

if 'publish' in sys.argv:
    if 'test' in sys.argv:
        os.system('python setup.py sdist bdist_wheel upload -rtest')
    else:
        pass
        # Build with: python setup.py sdist bdist_wheel
        # Upload with: twine upload --repository pypi dist/*1.2.3*  # For markdown to render, use twine
    sys.exit()


def read(fname):
    with open(os.path.join(os.path.dirname(__file__), fname)) as f:
        return f.read()


setup(
    name='django-mail-panel',
    version='3.1',
    description='A panel for django-debug-toolbar that allows for ' +
                'viewing of recently sent email.',
    url='https://github.com/scuml/django-mail-panel',

    license="Apache",
    long_description=read('README.md'),
    long_description_content_type="text/markdown",
    author='Stephen Mitchell',
    author_email='stephen@echodot.com',

    packages=find_packages(where="src"),
    package_dir={"": "src"},
    package_data={'': ['LICENSE']},

    install_requires=[
        'django>=2.2',
        'django-debug-toolbar>=3.0',
    ],
    include_package_data=True,
    zip_safe=False,                 # because we're including static files
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Intended Audience :: Developers',
        'Natural Language :: English',
        'Topic :: Internet :: WWW/HTTP',
        'License :: OSI Approved :: Apache Software License',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
    ],
)



from django.conf.urls import url
from .views import load_message, display_multipart, download_attachment

_PREFIX = 'mail_toolbar'

urlpatterns = [
    url(
        r'^{0}/load_message/(?P<message_id>[\w]+)/$'.format(_PREFIX),
        load_message,
        name="load_message"
    ),
    url(
        r'^{0}/download_attachment/(?P<message_id>[\w]+)/(?P<attachment_id>[\d]+)/$'.format(_PREFIX),
        download_attachment,
        name="download_attachment"
    ),
    url(
        r'^{0}/display_multipart/(?P<message_id>[\w]+)/(?P<multipart>[\w/]+)$'.format(_PREFIX),
        display_multipart,
        name="display_multipart"
    ),
]
